@@ -1,9 +1,15 @@
 import logging
 
-import sentry_sdk
+try:
+    import sentry_sdk
+    from sentry_sdk.integrations.asgi import SentryAsgiMiddleware
+except ImportError:
+    sentry = False
+else:
+    sentry = True
+
 from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
-from sentry_sdk.integrations.asgi import SentryAsgiMiddleware
 from starlette.requests import Request
 from starlette.responses import JSONResponse
 
@@ -13,23 +19,24 @@ from fractal.core.utils.settings import Settings
 
 
 def install_fastapi(settings: Settings):
-    app = FastAPI(root_path=settings.OPENAPI_PREFIX_PATH)
+    app = FastAPI(root_path=getattr(settings, "OPENAPI_PREFIX_PATH", ""))
 
     app.add_middleware(
         CORSMiddleware,
-        allow_origins=settings.ALLOW_ORIGINS,
+        allow_origins=getattr(settings, "ALLOW_ORIGINS", "").split(","),
         allow_credentials=True,
         allow_methods=["*"],
         allow_headers=["*"],
     )
 
-    sentry_sdk.init(dsn=settings.SENTRY_DSN)
-    app.add_middleware(
-        SentryAsgiMiddleware,
-    )
+    if sentry:
+        sentry_sdk.init(dsn=getattr(settings, "SENTRY_DSN", ""))
+        app.add_middleware(
+            SentryAsgiMiddleware,
+        )
 
     @app.exception_handler(DomainException)
-    def unicorn_exception_handler(request: Request, exc: DomainException):
+    def unicorn_domain_exception_handler(request: Request, exc: DomainException):
         logger = logging.getLogger("app")
         if isinstance(exc.status_code, int) and 400 <= exc.status_code < 500:
             logger.warning(f"{exc.code} - {exc.message}")
@@ -45,4 +52,16 @@ def install_fastapi(settings: Settings):
             headers=exc.headers,
         )
 
+    @app.exception_handler(Exception)
+    def unicorn_exception_handler(request: Request, exc: Exception):
+        logging.error(exc)
+
+        return JSONResponse(
+            status_code=500,
+            content=ErrorMessage(
+                code=exc.__class__.__name__,
+                message=str(exc),
+            ).dict(),
+        )
+
     return app
